#!/bin/bash
Current_DIR=$(cd `dirname $0`; pwd)
operatorSystem=`uname`
valuesFile=$Current_DIR/values.yaml
resetEntranceYamlTemplate=$Current_DIR/reset-entrance-template.yaml
resetEntranceYaml=$Current_DIR/reset-entrance.yaml

die() {
  echo "ERROR: $1"
  exit 2
}

# nsCount existNs ---> 1
# nsCount notExistNs ---> 0
# nsCount --> die namespace is empty
nsCount() {
  ns=$1
  [[ -z "$ns" ]] && die "namespace is empty"
  echo `kubectl get ns --ignore-not-found=true | awk -F ' ' '{ print $1 }' | grep "^$ns$" -c`
}

replaceFileContent() {
  if [[ `echo $operatorSystem | grep -ciw "Darwin"` = 1 ]]
  then
    # Mac
    sed -i '' $@
  else
    # Linux
    sed -i "$@"
  fi
}

getValueFromValues(){
  fileName=$2
  [[ -z $fileName ]] && fileName=$valuesFile
  index=$(sed -n '/'"$1":'/=' $fileName)
  if [ -z $index ];then
    echo ""
    return $?
  fi
  lineStr=$(cat $fileName | awk 'NR=='"$index"'')
  echo ${lineStr: $(expr length $1)+2}
  return $?
}

function waitTaskComplete(){
 completed=0;
 while [ $completed == 0 ]
 do
   completed=`kubectl get pod -n $ns | grep keycloak-reset-password | grep 'Completed' -c`
   sleep 2s
 done
}
[[ ! -f $valuesFile ]] && die "value.yaml is missing";

protocol=$(getValueFromValues deploy_imanager_service_protocol);
[[ -z $protocol ]] && protocol="http"
secure="false"
if [ "$protocol" = "https" ]; then
  secure="true"
fi
service_ip=$(getValueFromValues deploy_kubernetes_public_ip);
[[ -z $service_ip ]] && die "deploy_kubernetes_public_ip is empty"
service_port=$(getValueFromValues deploy_imanager_port)
[[ -z $service_port ]] && service_port="31100"
entrance_url="$protocol://$service_ip:$service_port"
current_time=$(date '+%s')
\cp $resetEntranceYamlTemplate $resetEntranceYaml
replaceFileContent 's|{$PROTOCOL$}|'$protocol'|g' $resetEntranceYaml
replaceFileContent 's|{$SECURE$}|'$secure'|g' $resetEntranceYaml
replaceFileContent 's|{$ENTRANCE_URL$}|'$entrance_url'|g' $resetEntranceYaml

ns=$(getValueFromValues deploy_namespace)
[[ -z "$ns" ]] && ns="supermap"
if [[ $(nsCount $ns) == 0 ]];then
  echo "namespace not exist: $ns"
else
  kubectl apply -f $resetEntranceYaml -n $ns
  kubectl patch Deployment/keycloak -p '{"spec": {"template": {"metadata": {"labels": {"patch.number": "'$current_time'"}}}}}' -n $ns --record
  kubectl patch Deployment/bslicense-server -p '{"spec": {"template": {"metadata": {"labels": {"patch.number": "'$current_time'"}}}}}' -n $ns --record
  kubectl patch Deployment/imanager-gateway -p 'spec:
  selector:
    matchLabels:
      app: imanager-gateway
  template:
    metadata:
      labels:
        patch.number: "'$current_time'"
    spec:
      containers:
        - name: imanager-gateway
          livenessProbe:
            httpGet:
              port: 9900
              scheme: '${protocol^^}'
              path: /actuator/health
          readinessProbe:
            httpGet:
              port: 9900
              scheme: '${protocol^^}'
              path: /actuator/health' -n $ns --record
  kubectl patch Deployment/imanager-dashboard-api -p '{"spec": {"template": {"metadata": {"labels": {"patch.number": "'$current_time'"}}}}}' -n $ns --record
  kubectl patch Deployment/imanager-phpmyadmin -p 'spec:
  selector:
    matchLabels:
      app: imanager-phpmyadmin
  template:
    spec:
      containers:
      - name: imanager-phpmyadmin
        env:
        - name: PMA_ABSOLUTE_URI
          value: '$entrance_url'/phpmyadmin/' -n $ns --record
  kubectl patch Ingress/imanager-ingress --type='json' -p '[{"op":"replace","path":"/metadata/annotations/nginx.ingress.kubernetes.io~1backend-protocol","value":"'$protocol'"},{"op":"replace","path":"/spec/tls/0/hosts/0","value":"none"},{"op":"replace","path":"/spec/rules/0/host","value":"none"}]' -n $ns --record
  echo "reset entrance successfully, please wait until the associated services to be ready.";
fi
