#!/bin/bash
Current_DIR=$(cd `dirname $0`; pwd)
operatorSystem=`uname`
valuesFile=$Current_DIR/values.yaml
resetPasswordYamlTemplate=$Current_DIR/reset-password-template.yaml
resetPasswordYaml=$Current_DIR/reset-password.yaml

die() {
  echo "ERROR: $1"
  exit 2
}

# nsCount existNs ---> 1
# nsCount notExistNs ---> 0
# nsCount --> die namespace is empty
nsCount() {
  ns=$1
  [[ -z "$ns" ]] && die "namespace is empty"
  echo `kubectl get ns --ignore-not-found=true | awk -F ' ' '{ print $1 }' | grep "^$ns$" -c`
}

replaceFileContent() {
  if [[ `echo $operatorSystem | grep -ciw "Darwin"` = 1 ]]
  then
    # Mac
    sed -i '' $@
  else
    # Linux
    sed -i "$@"
  fi
}

getValueFromValues(){
  fileName=$2
  [[ -z $fileName ]] && fileName=$valuesFile
  index=$(sed -n '/'"$1":'/=' $fileName)
  if [ -z $index ];then
    echo ""
    return $?
  fi
  lineStr=$(cat $fileName | awk 'NR=='"$index"'')
  echo ${lineStr: $(expr length $1)+2}
  return $?
}

function waitTaskComplete(){
 completed=0;
 while [ $completed == 0 ]
 do
   completed=`kubectl get pod -n $ns | grep keycloak-reset-password | grep 'Completed' -c`
   sleep 2s
 done
}
[[ ! -f $valuesFile ]] && die "value.yaml is missing";
registry=$(getValueFromValues deploy_registry);
[[ -z $registry ]] && registry="registry.cn-beijing.aliyuncs.com";
image_namespace=$(getValueFromValues deploy_image_namespace);
[[ -z $image_namespace ]] && image_namespace="supermap";
image_pull_secret=$(getValueFromValues deploy_image_pull_secret);
[[ -z $image_pull_secret ]] && image_pull_secret="image-pull-secret";
image_pull_policy=$(getValueFromValues deploy_image_pull_policy);
[[ -z $image_pull_policy ]] && image_pull_policy="IfNotPresent";
tiny_tools_image_tag=3.12-amd64
if [[ $(arch) == "aarch64" ]]; then
 tiny_tools_image_tag=1.0-arm64
fi
\cp $resetPasswordYamlTemplate $resetPasswordYaml
replaceFileContent "s|deploy_registry|$registry|g" $resetPasswordYaml
replaceFileContent "s|deploy_image_namespace|$image_namespace|g" $resetPasswordYaml
replaceFileContent "s|deploy_image_pull_secret|$image_pull_secret|g" $resetPasswordYaml
replaceFileContent "s|deploy_image_pull_policy|$image_pull_policy|g" $resetPasswordYaml
replaceFileContent "s|deploy_tiny_tools_image_tag|$tiny_tools_image_tag|g" $resetPasswordYaml

ns=$(getValueFromValues deploy_namespace)
[[ -z "$ns" ]] && ns="supermap"
if [[ $(nsCount $ns) == 0 ]];then
  echo "namespace not exist: $ns"
else
  kubectl delete job keycloak-reset-password -n $ns --ignore-not-found
  kubectl apply -f $resetPasswordYaml -n $ns
  echo "waiting for reset password..."
  waitTaskComplete;
  password=`kubectl get secret imanager-secret -n $ns -o=jsonpath="{.data['imanager\.password']}"`;
  echo "reset password successfully, new password is $(echo $password | base64 -d)";
  kubectl delete job keycloak-reset-password -n $ns --ignore-not-found=true
fi
