#bin/sh
Current_DIR=$(cd `dirname $0`; pwd)
delete_volume=$1
valuesFile=$Current_DIR/values.yaml

getValueFromValues(){
  fileName=$2
  [[ -z $fileName ]] && fileName=$valuesFile
  index=$(sed -n '/'"$1":'/=' $fileName)
  if [ -z $index ];then
    echo ""
    return $?
  fi
  lineStr=$(cat $fileName | awk 'NR=='"$index"'')
  echo ${lineStr: $(expr length $1)+2}
  return $?
}

ns=$(getValueFromValues deploy_namespace)
[[ -z "$ns" ]] && ns="supermap"

function waitingPodsDelete(){
  podCount=`kubectl get pods --ignore-not-found=true --no-headers=true $@ | grep . -c`
  while [ $podCount -gt 0 ]
  do
    sleep 2s
    podCount=`kubectl get pods --ignore-not-found=true --no-headers=true $@ | grep . -c`
  done
}

function deleteResource(){
  kubectl delete deploy,daemonset,statefulset,job,cronjob,configmap,service,serviceaccount,role,rolebinding --ignore-not-found=true $@
}

function deleteNS(){
  for p in $@;
  do
     if [ -n "$p" ]; then
        deleteKnative --all -n $p
        deleteResource --all -n $p
        waitingPodsDelete -n $p
        kubectl delete pvc --all -n $p
        kubectl delete ns $p
     fi
  done;
}

function deletePV(){
  for p in $@;
  do
     if [ -n "$p" ]; then
        pvName=$(kubectl get pv --ignore-not-found=true | grep $p | awk '{print $1}')
        [[ -n $pvName ]] && kubectl delete pv $pvName
        kubectl delete storageclass $p
     fi
  done;
}

function deleteCreatedResource(){
  nsCount=`kubectl get ns -l kind=imanager-base --ignore-not-found=true | grep . -c`
  if [[ $nsCount -gt 0 ]];then
    deleteNS $(kubectl get ns -l kind=imanager-base --no-headers=true | awk '{print $1}')
  fi
}

function deletePVResource(){
  storageclassCount=`kubectl get storageclass -l kind=imanager-base --ignore-not-found=true | grep . -c`
  if [[ $storageclassCount -gt 0 ]];then
    deletePV $(kubectl get storageclass -l kind=imanager-base --no-headers=true | awk '{print $1}')
  fi
    pvCount=`kubectl get pv --ignore-not-found=true  --no-headers=true -l kind=imanager-base | grep . -c`
  if [[ $pvCount -gt 0 ]];then
     kubectl get pv --ignore-not-found=true  --no-headers=true -l kind=imanager-base | awk '{print $1}' | xargs kubectl delete pv
  fi
}

function deleteClusterResource(){
  kubectl delete clusterrole,clusterrolebinding --ignore-not-found=true $@
}

function deleteIstio() {
  deploy_istio_enabled=$(getValueFromValues deploy_istio_enabled)
  if [[ "$deploy_istio_enabled" == "true" ]] && [[ `kubectl get ns istio-system -o template --template='{{index .metadata.labels "imanager-base"}}'` == "true" ]]; then
    . $Current_DIR/istio.sh close
    kubectl label ns istio-system imanager-base-
  fi
}
function deleteKnative() {
  if [[ -n $(kubectl explain ksvc 2>/dev/null) ]]; then
    kubectl delete ksvc $@
  fi
}

msg="Are you sure you want to uninstall iManager? [Y/N] ";
if [[ "$delete_volume" == "-v" ]]; then
  msg="All sites and PersistentVolumes(PVs) that you created will be removed from the system. Do you still want to uninstall iManager? [Y/N] "
fi
read -r -p "$msg" input
case $input in
[yY][eE][sS]|[yY])
;;
*)
exit 1;
;;
esac

if [[ "$delete_volume" == "-v" ]]; then
  deleteKnative -l kind=imanager-base -n $ns
  deleteCreatedResource
  $Current_DIR/helm uninstall imanager -n $ns
  deleteResource -l kind=imanager-base -n $ns
  kubectl delete pvc -l kind=imanager-base -n $ns --ignore-not-found=true
  deletePVResource
  deleteIstio
  if [[ "$ns" != "default" && "$ns" != "kube-system" && "$ns" != "kube-public" ]]; then
    kubectl delete ns $ns
  fi
  deleteClusterResource -l kind=imanager-base
else
  kubectl delete deploy,daemonset,statefulset,job,service,serviceaccount,role,rolebinding --ignore-not-found=true -l kind=imanager-base -n $ns
  kubectl delete storageclass -l kind=imanager-base --ignore-not-found=true
fi
